@@ -1,10 +1,11 @@
-#'@title Clustering Tune
-#'@description Creates an object for tuning clustering models.
-#'This object can be used to fit and optimize clustering algorithms by specifying hyperparameter ranges
+#'@title Clustering tuning (intrinsic metric)
+#'@description Tune clustering hyperparameters by evaluating an intrinsic metric over a parameter grid and selecting the elbow (max curvature).
 #'@param base_model base model for tuning
 #'@param folds number of folds for cross-validation
 #'@param ranges a list of hyperparameter ranges to explore
 #'@return returns a `clu_tune` object.
+#'@references
+#' Satopaa, V. et al. (2011). Finding a “Kneedle” in a Haystack.
 #'@examples
 #'data(iris)
 #'
@@ -50,7 +51,7 @@ fit.clu_tune <- function(obj, data, ...) {
   n <- nrow(ranges)
   i <- 1
   if (n > 1) {
-    msg <- rep("", n) #save later msg in hyper parameters
+    msg <- rep("", n) # store errors per configuration
     for (i in 1:n) {
       err <- tryCatch(
         {
@@ -66,6 +67,7 @@ fit.clu_tune <- function(obj, data, ...) {
         msg[i] <- err
       }
     }
+    # choose parameter at the elbow of metric curve (max curvature)
     myfit <- fit_curvature_max()
     res <- transform(myfit, ranges$metric)
     i <- res$x
